@@ -14,14 +14,21 @@
 # along with this programe.  If not, see <http://www.gnu.org/licenses/>.
 try:
     from threading import local
-    from merengue.base.admin import BaseAdmin
 except ImportError:
-    from django.contrib.admin import ModelAdmin as BaseAdmin
     from django.utils._threading_local import local
+
+try:
+    from merengue.base.admin import BaseAdmin
+    from merengue.base.adminsite import site
+except ImportError:
+    from django.contrib.admin import site
+    from django.contrib.admin import ModelAdmin as BaseAdmin
+
+from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import PermissionDenied
 
-from genericforeignkey.utils import get_objects_of_content_type
+from genericforeignkey.utils import clear_content_type, get_objects_of_content_type
 
 
 _thread_locals = local()
@@ -52,12 +59,25 @@ class GenericContentTypeAdmin(BaseAdmin):
     class Media:
         js = ("genericforeignkey/js/content_type_object.js", )
 
+    def search_modeladmin(self):
+        for model in self.model.mro():
+            if model in site._registry:
+                return site._registry[model]
+        return None
+
     def changelist_view(self, request, extra_context=None):
-        extra_context = self._base_update_extra_context(extra_context)
+        extra_context = self._base_update_extra_context(extra_context) or {}
         content_type_id = request.GET.get('content_type_id', None)
         if content_type_id:
             content_type = ContentType.objects.get(pk=content_type_id)
             self.model = content_type.model_class()
+            if settings.SEARCH_MODELADMIN:
+                model_admin = self.search_modeladmin()
+                if model_admin:
+                    clear_content_type(request)
+                    extra_context['search_mode'] = True
+                    extra_context['generic_fk_media'] = self.media
+                    return model_admin.changelist_view(request, extra_context)
         else:
             self.model = ContentType
         return super(GenericContentTypeAdmin, self).changelist_view(request, extra_context)
